'use client';

import { useState, useEffect } from 'react';
import Link from 'next/link';
import { Album } from '@/entities/album.entity';
import CreateAlbumModal from "@/app/components/modals/create-album";
import { Suspense } from "react";

export default function Page() {
  const [albums, setAlbums] = useState<Album[]>([]);

  useEffect(() => {
    async function fetchAlbums() {
      const response = await fetch('https://api.anatid.net/album');
      const data = await response.json();
      setAlbums(data);
    }
    fetchAlbums();
  }, []);

  if (!albums) return <div>Loading...</div>

  return (
    <div className="container">
      <Link href="?modal=true">
          <button type="button" className="bg-blue-500 text-white p-2">Open Modal</button>
      </Link>
      <table className="u-full-width">
        <thead>
          <tr>
            <th>Title</th>
            <th>Artist</th>
            <th>Genre</th>
            <th>Controls</th>
          </tr>
        </thead>
        <tbody>
        {albums.map((album: Album) => (
          <tr key={album.id}>
            <td>
              <Link
                href={{
                  pathname: `/album/${album.id}`
                }}>{album.title}
              </Link>
            </td>
            <td>
              {album.artist}
            </td>
            <td>
              {album.genre}
            </td>
            <td></td>
          </tr>
        ))}
        </tbody>
      </table>
      <Suspense>
        <CreateAlbumModal/>
      </Suspense>
    </div>
  );
}
