"use client";

import { FormEvent } from 'react';
import {useSearchParams, usePathname} from "next/navigation";
import Link from "next/link";
import { createAlbum } from '@/app/actions';
import { useRouter } from 'next/navigation';

function CreateAlbumModal() {
    const searchParams = useSearchParams();
    const modal = searchParams.get("modal");
    const pathname = usePathname();
    const router = useRouter();

    async function onSubmit(event: FormEvent<HTMLFormElement>) {
      event.preventDefault();

      const formData = new FormData(event.currentTarget);
      const response = await createAlbum(formData);

      await response.json();
      router.refresh();
    }

    return (
        <>
            {modal &&
                <dialog
                    className="fixed left-0 top-0 w-full h-full bg-black bg-opacity-50 z-50 overflow-auto backdrop-blur flex justify-center items-center">
                    <div className="container">
                      <form onSubmit={onSubmit}>
                        <div className="row">
                          <div className="six columns">
                            <label htmlFor="album-title">Album Title</label><input type="text" name="title" id="album-title" />
                          </div>
                          <div className="six columns">
                            <label htmlFor="album-artist">Artist</label><input type="text" name="artist" id="album-artist" />
                          </div>
                        </div>
                        <div className="row">
                          <div className="six columns">
                            <label htmlFor="album-genre">Genre</label><input type="text" name="genre" id="album-genre" />
                          </div>
                        </div>
                        <div className="row">
                          <div className="six columns">
                            <button type="submit">Create</button>
                          </div>
                        </div>
                      </form>
                        <Link href={pathname}>
                            <button type="button" className="bg-red-500 text-white p-2">Close Modal</button>
                        </Link>
                    </div>
                </dialog>
            }
        </>
    );
}

export default CreateAlbumModal;
